package Lagrange::PartialDerivative;

use parent 'Lagrange::Derivative';

sub new {
	my ($class, $name) = @_;
        my $self = $class->SUPER::new;

}

1;
